@@ -5,6 +5,10 @@ class Palette:
         self.metadata = metadata if metadata is not None else {}
 
 
+    def __getitem__(self, i):
+        return self.colors[i]
+
+
     def __repr__(self):
         display = f"Palette {self.name} ({len(self.colors)} colors)\n"
         display += "\n".join([ f"- {[i]} {color.__repr__()}" for i, color in enumerate(self.colors) ])
